@@ -5,14 +5,18 @@ import os
 import shutil
 import sys
 import platform
+import warnings
 
 import fsspec
-import imageio
+import imageio.plugins
+import imageio.v3 as iio3
+import imageio.v2 as iio
 import numpy as np
 import pytest
 from imageio import core
 from imageio.core import IS_PYPY
 from pytest import raises, skip
+from conftest import deprecated_test
 
 
 @pytest.fixture(scope="module")
@@ -41,6 +45,7 @@ def vendored_lib(request, tmp_path_factory):
     yield lib_dir
 
 
+# TODD: update fixture once we transition into v3
 @pytest.fixture(scope="module")
 def setup_library(tmp_path_factory, vendored_lib):
 
@@ -50,7 +55,8 @@ def setup_library(tmp_path_factory, vendored_lib):
     use_imageio_binary = not fi.has_lib()
 
     # During this test, pretend that FI is the default format
-    imageio.formats.sort("-FI")
+    with warnings.catch_warnings(record=True):
+        iio.formats.sort("-FI")
 
     if use_imageio_binary:
 
@@ -81,7 +87,8 @@ def setup_library(tmp_path_factory, vendored_lib):
             del os.environ[user_dir_env]
 
     # Sort formats back to normal
-    imageio.formats.sort()
+    with warnings.catch_warnings(record=True):
+        iio.formats.sort()
 
 
 # Create test images LUMINANCE
@@ -183,12 +190,13 @@ def test_get_fi_lib(vendored_lib, tmp_userdir):
     assert os.path.isfile(lib)
 
 
+@deprecated_test
 def test_freeimage_format(setup_library, test_images, tmp_path):
 
     fnamebase = str(tmp_path / "test")
 
     # Format
-    F = imageio.formats["PNG-FI"]
+    F = iio.formats["PNG-FI"]
     assert F.name == "PNG-FI"
 
     # Reader
@@ -231,8 +239,8 @@ def test_png(setup_library, test_images, tmp_path):
             for colors in (0, 1, 3, 4):
                 fname = fnamebase + "%i.%i.%i.png" % (isfloat, crop, colors)
                 rim = get_ref_im(colors, crop, isfloat)
-                imageio.imsave(fname, rim)
-                im = imageio.imread(fname)
+                iio.imsave(fname, rim)
+                im = iio.imread(fname)
                 mul = 255 if isfloat else 1
                 assert_close(rim * mul, im, 0.1)  # lossless
 
@@ -244,49 +252,49 @@ def test_png(setup_library, test_images, tmp_path):
                 for colors in (0, 1, 3, 4):
                     fname = fnamebase + "%i.%i.%i.png" % (isfloat, crop, colors)
                     rim = get_ref_im(colors, crop, isfloat)
-                    imageio.imsave(fname, rim)
-                    im = imageio.imread(fname)
+                    iio.imsave(fname, rim)
+                    im = iio.imread(fname)
                     mul = 255 if isfloat else 1
                     assert_close(rim * mul, im, 0.1)  # lossless
     finally:
         imageio.plugins._freeimage.TEST_NUMPY_NO_STRIDES = False
 
     # Parameters
-    im = imageio.imread(test_images / "chelsea.png", ignoregamma=True)
-    imageio.imsave(fnamebase + ".png", im, interlaced=True)
+    im = iio.imread(test_images / "chelsea.png", ignoregamma=True)
+    iio.imsave(fnamebase + ".png", im, interlaced=True)
 
     # Parameter fail
     raises(
         TypeError,
-        imageio.imread,
+        iio.imread,
         test_images / "chelsea.png",
         notavalidk=True,
     )
-    raises(TypeError, imageio.imsave, fnamebase + ".png", im, notavalidk=True)
+    raises(TypeError, iio.imsave, fnamebase + ".png", im, notavalidk=True)
 
     # Compression
-    imageio.imsave(fnamebase + "1.png", im, compression=0)
-    imageio.imsave(fnamebase + "2.png", im, compression=9)
+    iio.imsave(fnamebase + "1.png", im, compression=0)
+    iio.imsave(fnamebase + "2.png", im, compression=9)
     s1 = os.stat(fnamebase + "1.png").st_size
     s2 = os.stat(fnamebase + "2.png").st_size
     assert s2 < s1
     # Fail
-    raises(ValueError, imageio.imsave, fnamebase + ".png", im, compression=12)
+    raises(ValueError, iio.imsave, fnamebase + ".png", im, compression=12)
 
     # Quantize
     if sys.platform.startswith("darwin"):
         return  # quantization segfaults on my osx VM
-    imageio.imsave(fnamebase + "1.png", im, quantize=256)
-    imageio.imsave(fnamebase + "2.png", im, quantize=4)
+    iio.imsave(fnamebase + "1.png", im, quantize=256)
+    iio.imsave(fnamebase + "2.png", im, quantize=4)
 
-    im = imageio.imread(fnamebase + "2.png")  # touch palette read code
+    im = iio.imread(fnamebase + "2.png")  # touch palette read code
     s1 = os.stat(fnamebase + "1.png").st_size
     s2 = os.stat(fnamebase + "2.png").st_size
     assert s1 > s2
     # Fail
     fname = fnamebase + "1.png"
-    raises(ValueError, imageio.imsave, fname, im[:, :, :3], quantize=300)
-    raises(ValueError, imageio.imsave, fname, im[:, :, 0], quantize=100)
+    raises(ValueError, iio.imsave, fname, im[:, :, :3], quantize=300)
+    raises(ValueError, iio.imsave, fname, im[:, :, 0], quantize=100)
 
 
 def test_png_dtypes(setup_library, tmp_path):
@@ -304,28 +312,28 @@ def test_png_dtypes(setup_library, tmp_path):
     fname = fnamebase + ".dtype.png"
 
     # uint8
-    imageio.imsave(fname, im1)
-    assert_close(im1, imageio.imread(fname))
-    imageio.imsave(fname, im2)
-    assert_close(im2, imageio.imread(fname))
+    iio.imsave(fname, im1)
+    assert_close(im1, iio.imread(fname))
+    iio.imsave(fname, im2)
+    assert_close(im2, iio.imread(fname))
 
     # float scaled
-    imageio.imsave(fname, im1 / 255.0)
-    assert_close(im1, imageio.imread(fname))
-    imageio.imsave(fname, im2 / 255.0)
-    assert_close(im2, imageio.imread(fname))
+    iio.imsave(fname, im1 / 255.0)
+    assert_close(im1, iio.imread(fname))
+    iio.imsave(fname, im2 / 255.0)
+    assert_close(im2, iio.imread(fname))
 
     # float not scaled
-    imageio.imsave(fname, im1 * 1.0)
-    assert_close(im1, imageio.imread(fname))
-    imageio.imsave(fname, im2 * 1.0)
-    assert_close(im1, imageio.imread(fname))  # scaled
+    iio.imsave(fname, im1 * 1.0)
+    assert_close(im1, iio.imread(fname))
+    iio.imsave(fname, im2 * 1.0)
+    assert_close(im1, iio.imread(fname))  # scaled
 
     # int16
-    imageio.imsave(fname, im1.astype("int16"))
-    assert_close(im1, imageio.imread(fname))
-    imageio.imsave(fname, im2.astype("int16"))
-    assert_close(im1, imageio.imread(fname))  # scaled
+    iio.imsave(fname, im1.astype("int16"))
+    assert_close(im1, iio.imread(fname))
+    iio.imsave(fname, im2.astype("int16"))
+    assert_close(im1, iio.imread(fname))  # scaled
 
 
 def test_jpg(setup_library, tmp_path):
@@ -337,30 +345,28 @@ def test_jpg(setup_library, tmp_path):
             for colors in (0, 1, 3):
                 fname = fnamebase + "%i.%i.%i.jpg" % (isfloat, crop, colors)
                 rim = get_ref_im(colors, crop, isfloat)
-                imageio.imsave(fname, rim)
-                im = imageio.imread(fname)
+                iio.imsave(fname, rim)
+                im = iio.imread(fname)
                 mul = 255 if isfloat else 1
                 assert_close(rim * mul, im, 1.1)  # lossy
 
     # No alpha in JPEG
-    raises(Exception, imageio.imsave, fname, im4)
+    raises(Exception, iio.imsave, fname, im4)
 
     # Parameters
-    imageio.imsave(
-        fnamebase + ".jpg", im3, progressive=True, optimize=True, baseline=True
-    )
+    iio.imsave(fnamebase + ".jpg", im3, progressive=True, optimize=True, baseline=True)
 
     # Parameter fail
     raises(
         TypeError,
-        imageio.imread,
+        iio.imread,
         fnamebase + ".jpg",
         notavalidkwarg=True,
         format="JPEG-FI",
     )
     raises(
         TypeError,
-        imageio.imsave,
+        iio.imsave,
         fnamebase + ".jpg",
         im,
         notavalidk=True,
@@ -368,12 +374,12 @@ def test_jpg(setup_library, tmp_path):
     )
 
     # Compression
-    imageio.imsave(fnamebase + "1.jpg", im3, quality=10)
-    imageio.imsave(fnamebase + "2.jpg", im3, quality=90)
+    iio.imsave(fnamebase + "1.jpg", im3, quality=10)
+    iio.imsave(fnamebase + "2.jpg", im3, quality=90)
     s1 = os.stat(fnamebase + "1.jpg").st_size
     s2 = os.stat(fnamebase + "2.jpg").st_size
     assert s2 > s1
-    raises(ValueError, imageio.imsave, fnamebase + ".jpg", im, quality=120)
+    raises(ValueError, iio.imsave, fnamebase + ".jpg", im, quality=120)
 
 
 def test_jpg_more(setup_library, test_images, tmp_path):
@@ -383,29 +389,29 @@ def test_jpg_more(setup_library, test_images, tmp_path):
     # Test broken JPEG
     fname = fnamebase + "_broken.jpg"
     open(fname, "wb").write(b"this is not an image")
-    raises(Exception, imageio.imread, fname)
+    raises(Exception, iio.imread, fname)
     #
     img = get_ref_im(3, 0, 0)
-    bb = imageio.imsave(imageio.RETURN_BYTES, img, "JPEG-FI")
+    bb = iio.imsave(iio.RETURN_BYTES, img, "JPEG-FI")
     with open(fname, "wb") as f:
         f.write(bb[:400])
         f.write(b" ")
         f.write(bb[400:])
-    raises(Exception, imageio.imread, fname)
+    raises(Exception, iio.imread, fname)
 
     # Test EXIF stuff
     fname = test_images / "rommel.jpg"
-    im = imageio.imread(fname)
+    im = iio.imread(fname)
     assert im.shape[0] > im.shape[1]
-    im = imageio.imread(fname, exifrotate=False)
+    im = iio.imread(fname, exifrotate=False)
     assert im.shape[0] < im.shape[1]
-    im = imageio.imread(fname, exifrotate=2)  # Rotation in Python
+    im = iio.imread(fname, exifrotate=2)  # Rotation in Python
     assert im.shape[0] > im.shape[1]
     # Write the jpg and check that exif data is maintained
     if sys.platform.startswith("darwin"):
         return  # segfaults on my osx VM, why?
-    imageio.imsave(fnamebase + "rommel.jpg", im)
-    im = imageio.imread(fname)
+    iio.imsave(fnamebase + "rommel.jpg", im)
+    im = iio.imread(fname)
     assert im.meta.EXIF_MAIN
 
 
@@ -418,14 +424,14 @@ def test_bmp(setup_library, tmp_path):
             for colors in (0, 1, 3, 4):
                 fname = fnamebase + "%i.%i.%i.bmp" % (isfloat, crop, colors)
                 rim = get_ref_im(colors, crop, isfloat)
-                imageio.imsave(fname, rim, format="BMP-FI")
-                im = imageio.imread(fname, format="BMP-FI")
+                iio.imsave(fname, rim, format="BMP-FI")
+                im = iio.imread(fname, format="BMP-FI")
                 mul = 255 if isfloat else 1
                 assert_close(rim * mul, im, 0.1)  # lossless
 
     # Compression
-    imageio.imsave(fnamebase + "1.bmp", im3, compression=False, format="BMP-FI")
-    imageio.imsave(fnamebase + "2.bmp", im3, compression=True, format="BMP-FI")
+    iio.imsave(fnamebase + "1.bmp", im3, compression=False, format="BMP-FI")
+    iio.imsave(fnamebase + "2.bmp", im3, compression=True, format="BMP-FI")
     s1 = os.stat(fnamebase + "1.bmp").st_size
     s2 = os.stat(fnamebase + "2.bmp").st_size
     assert s1 + s2  # todo: bug in FreeImage? assert s1 < s2
@@ -433,14 +439,14 @@ def test_bmp(setup_library, tmp_path):
     # Parameter fail
     raises(
         TypeError,
-        imageio.imread,
+        iio.imread,
         fnamebase + "1.bmp",
         notavalidkwarg=True,
         format="BMP-FI",
     )
     raises(
         TypeError,
-        imageio.imsave,
+        iio.imsave,
         fnamebase + "1.bmp",
         im,
         notavalidk=True,
@@ -461,8 +467,8 @@ def test_gif(setup_library, tmp_path):
                     continue  # quantize fails, see also png
                 fname = fnamebase + "%i.%i.%i.gif" % (isfloat, crop, colors)
                 rim = get_ref_im(colors, crop, isfloat)
-                imageio.imsave(fname, rim, format="GIF-FI")
-                im = imageio.imread(fname, format="GIF-FI")
+                iio.imsave(fname, rim, format="GIF-FI")
+                im = iio.imread(fname, format="GIF-FI")
                 mul = 255 if isfloat else 1
                 if colors in (0, 1):
                     im = im[:, :, 0]
@@ -472,10 +478,10 @@ def test_gif(setup_library, tmp_path):
                 assert_close(rim * mul, im, 1.1)  # lossless
 
     # Parameter fail
-    raises(TypeError, imageio.imread, fname, notavalidkwarg=True, format="GIF-FI")
+    raises(TypeError, iio.imread, fname, notavalidkwarg=True, format="GIF-FI")
     raises(
         TypeError,
-        imageio.imsave,
+        iio.imsave,
         fnamebase + "1.gif",
         im,
         notavalidk=True,
@@ -506,9 +512,9 @@ def test_animated_gif(setup_library, tmp_path):
                 ims1 = [x.astype(np.float32) / 256 for x in ims1]
             ims1 = [x[:, :, :colors] for x in ims1]
             fname = fnamebase + ".animated.%i.gif" % colors
-            imageio.mimsave(fname, ims1, duration=0.2, format="GIF-FI")
+            iio.mimsave(fname, ims1, duration=0.2, format="GIF-FI")
             # Retrieve
-            ims2 = imageio.mimread(fname, format="GIF-FI")
+            ims2 = iio.mimread(fname, format="GIF-FI")
             ims1 = [x[:, :, :3] for x in ims]  # fresh ref
             ims2 = [x[:, :, :3] for x in ims2]  # discart alpha
             for im1, im2 in zip(ims1, ims2):
@@ -516,23 +522,21 @@ def test_animated_gif(setup_library, tmp_path):
 
     # We can also store grayscale
     fname = fnamebase + ".animated.%i.gif" % 1
-    imageio.mimsave(fname, [x[:, :, 0] for x in ims], duration=0.2, format="GIF-FI")
-    imageio.mimsave(fname, [x[:, :, :1] for x in ims], duration=0.2, format="GIF-FI")
+    iio.mimsave(fname, [x[:, :, 0] for x in ims], duration=0.2, format="GIF-FI")
+    iio.mimsave(fname, [x[:, :, :1] for x in ims], duration=0.2, format="GIF-FI")
 
     # Irragular duration. You probably want to check this manually (I did)
     duration = [0.1 for i in ims]
     for i in [2, 5, 7]:
         duration[i] = 0.5
-    imageio.mimsave(
+    iio.mimsave(
         fnamebase + ".animated_irr.gif", ims, duration=duration, format="GIF-FI"
     )
 
     # Other parameters
-    imageio.mimsave(
-        fnamebase + ".animated.loop2.gif", ims, loop=2, fps=20, format="GIF-FI"
-    )
-    R = imageio.read(fnamebase + ".animated.loop2.gif", format="GIF-FI")
-    W = imageio.save(
+    iio.mimsave(fnamebase + ".animated.loop2.gif", ims, loop=2, fps=20, format="GIF-FI")
+    R = iio.read(fnamebase + ".animated.loop2.gif", format="GIF-FI")
+    W = iio.save(
         fnamebase + ".animated.palettes100.gif",
         palettesize=100,
         format="GIF-FI",
@@ -540,29 +544,29 @@ def test_animated_gif(setup_library, tmp_path):
     assert W._palettesize == 128
     # Fail
     raises(IndexError, R.get_meta_data, -1)
-    raises(ValueError, imageio.mimsave, fname, ims, palettesize=300)
+    raises(ValueError, iio.mimsave, fname, ims, palettesize=300)
     raises(
         ValueError,
-        imageio.mimsave,
+        iio.mimsave,
         fname,
         ims,
         quantizer="foo",
         format="GIF-FI",
     )
-    raises(ValueError, imageio.mimsave, fname, ims, duration="foo", format="GIF-FI")
+    raises(ValueError, iio.mimsave, fname, ims, duration="foo", format="GIF-FI")
 
     # Add one duplicate image to ims to touch subractangle with not change
     ims.append(ims[-1])
 
     # Test subrectangles
-    imageio.mimsave(fnamebase + ".subno.gif", ims, subrectangles=False, format="GIF-FI")
-    imageio.mimsave(fnamebase + ".subyes.gif", ims, subrectangles=True, format="GIF-FI")
+    iio.mimsave(fnamebase + ".subno.gif", ims, subrectangles=False, format="GIF-FI")
+    iio.mimsave(fnamebase + ".subyes.gif", ims, subrectangles=True, format="GIF-FI")
     s1 = os.stat(fnamebase + ".subno.gif").st_size
     s2 = os.stat(fnamebase + ".subyes.gif").st_size
     assert s2 < s1
 
     # Meta (dummy, because always {}
-    assert isinstance(imageio.read(fname).get_meta_data(), dict)
+    assert isinstance(iio.read(fname).get_meta_data(), dict)
 
 
 def test_ico(setup_library, tmp_path):
@@ -575,29 +579,29 @@ def test_ico(setup_library, tmp_path):
                 fname = fnamebase + "%i.%i.%i.ico" % (isfloat, crop, colors)
                 rim = get_ref_im(colors, crop, isfloat)
                 rim = rim[:32, :32]  # ico needs nice size
-                imageio.imsave(fname, rim, format="ICO-FI")
-                im = imageio.imread(fname, format="ICO-FI")
+                iio.imsave(fname, rim, format="ICO-FI")
+                im = iio.imread(fname, format="ICO-FI")
                 mul = 255 if isfloat else 1
                 assert_close(rim * mul, im, 0.1)  # lossless
 
     # Meta data
-    R = imageio.read(fnamebase + "0.0.1.ico", format="ICO-FI")
+    R = iio.read(fnamebase + "0.0.1.ico", format="ICO-FI")
     assert isinstance(R.get_meta_data(0), dict)
     assert isinstance(R.get_meta_data(None), dict)  # But this print warning
     R.close()
-    writer = imageio.save(fnamebase + "I.ico", format="ICO-FI")
+    writer = iio.save(fnamebase + "I.ico", format="ICO-FI")
     writer.set_meta_data({})
     writer.close()
 
     # Parameters. Note that with makealpha, RGBA images are read in incorrectly
-    im = imageio.imread(fnamebase + "0.0.1.ico", makealpha=True, format="ICO-FI")
+    im = iio.imread(fnamebase + "0.0.1.ico", makealpha=True, format="ICO-FI")
     assert im.ndim == 3 and im.shape[-1] == 4
 
     # Parameter fail
-    raises(TypeError, imageio.imread, fname, notavalidkwarg=True, format="ICO-FI")
+    raises(TypeError, iio.imread, fname, notavalidkwarg=True, format="ICO-FI")
     raises(
         TypeError,
-        imageio.imsave,
+        iio.imsave,
         fnamebase + "1.ico",
         im,
         notavalidk=True,
@@ -617,15 +621,15 @@ def test_multi_icon_ico(setup_library, tmp_path):
     im = get_ref_im(4, 0, 0)[:32, :32]
     ims = [np.repeat(np.repeat(im, i, 1), i, 0) for i in (1, 2)]  # SegF on win
     ims = im, np.column_stack((im, im)), np.row_stack((im, im))  # error on win
-    imageio.mimsave(fnamebase + "I2.ico", ims, format="ICO-FI")
-    ims2 = imageio.mimread(fnamebase + "I2.ico", format="ICO-FI")
+    iio.mimsave(fnamebase + "I2.ico", ims, format="ICO-FI")
+    ims2 = iio.mimread(fnamebase + "I2.ico", format="ICO-FI")
     for im1, im2 in zip(ims, ims2):
         assert_close(im1, im2, 0.1)
 
 
 @pytest.mark.skip("MNG seems broken in FreeImage")
 def test_mng(setup_library, test_images):
-    imageio.imread(test_images / "mngexample.mng")
+    iio.imread(test_images / "mngexample.mng")
 
 
 def test_pnm(setup_library, tmp_path):
@@ -638,21 +642,21 @@ def test_pnm(setup_library, tmp_path):
                 fname = fnamebase
                 fname += "%i.%i.%i.ppm" % (useAscii, crop, colors)
                 rim = get_ref_im(colors, crop, isfloat=False)
-                imageio.imsave(fname, rim, use_ascii=useAscii, format="PPM-FI")
-                im = imageio.imread(fname, format="PPM-FI")
+                iio.imsave(fname, rim, use_ascii=useAscii, format="PPM-FI")
+                im = iio.imread(fname, format="PPM-FI")
                 assert_close(rim, im, 0.1)  # lossless
 
                 # Parameter fail
                 raises(
                     TypeError,
-                    imageio.imread,
+                    iio.imread,
                     fname,
                     notavalidkwarg=True,
                     format="PPM-FI",
                 )
                 raises(
                     TypeError,
-                    imageio.imsave,
+                    iio.imsave,
                     fname,
                     im,
                     notavalidk=True,
@@ -665,7 +669,7 @@ def test_other(setup_library, tmp_path):
 
     # Cannot save float
     im = get_ref_im(3, 0, 1)
-    raises(Exception, imageio.imsave, fnamebase + ".jng", im, "JNG")
+    raises(Exception, iio.imsave, fnamebase + ".jng", im, "JNG")
 
 
 def test_gamma_correction(setup_library, test_images):
@@ -673,9 +677,9 @@ def test_gamma_correction(setup_library, test_images):
     fname = test_images / "kodim03.png"
 
     # Load image three times
-    im1 = imageio.imread(fname, format="PNG-FI")
-    im2 = imageio.imread(fname, ignoregamma=True, format="PNG-FI")
-    im3 = imageio.imread(fname, ignoregamma=False, format="PNG-FI")
+    im1 = iio.imread(fname, format="PNG-FI")
+    im2 = iio.imread(fname, ignoregamma=True, format="PNG-FI")
+    im3 = iio.imread(fname, ignoregamma=False, format="PNG-FI")
 
     # Default is to ignore gamma
     assert np.all(im1 == im2)
@@ -692,7 +696,7 @@ def test_gamma_correction(setup_library, test_images):
 
 
 def test_improps(test_images):
-    props = imageio.v3.improps(test_images / "kodim03.png", plugin="PNG-FI")
+    props = iio3.improps(test_images / "kodim03.png", plugin="PNG-FI")
 
     assert props.shape == (512, 768, 3)
     assert props.dtype == np.uint8
