@@ -74,61 +74,6 @@ def test_write_multiframe(test_images, tmp_path, im_npy, im_out, im_comp):
     assert iio_file.read_bytes() == pil_file.read_bytes()
 
 
-@pytest.mark.parametrize(
-    "im_in,mode",
-    [
-        ("chelsea.png", "RGB"),
-        ("chelsea.jpg", "RGB"),
-        ("chelsea.bmp", "RGB"),
-        ("newtonscradle.gif", "RGB"),
-        ("newtonscradle.gif", "RGBA"),
-    ],
-)
-def test_read(test_images, im_in, mode):
-    im_path = test_images / im_in
-    iio_im = iio.v3.imread(im_path, plugin="pillow", mode=mode, index=None)
-
-    pil_im = np.asarray(
-        [
-            np.array(frame.convert(mode))
-            for frame in ImageSequence.Iterator(Image.open(im_path))
-        ]
-    )
-
-    assert np.allclose(iio_im, pil_im)
-
-
-@pytest.mark.parametrize(
-    "im_in,mode",
-    [
-        ("newtonscradle.gif", "RGB"),
-        ("newtonscradle.gif", "RGBA"),
-    ],
-)
-def test_gif_legacy_pillow(test_images, im_in, mode):
-    """
-    This test tests backwards compatibility of using the new API
-    with a legacy plugin. IN particular reading ndimages
-
-    I'm not sure where this test should live, so it is here for now.
-    """
-
-    im_path = test_images / im_in
-    with iio.imopen(im_path, "r", legacy_mode=True, plugin="GIF-PIL") as file:
-        iio_im = file.read(pilmode=mode, index=None)
-
-    pil_im = np.asarray(
-        [
-            np.array(frame.convert(mode))
-            for frame in ImageSequence.Iterator(Image.open(im_path))
-        ]
-    )
-    if pil_im.shape[0] == 1:
-        pil_im = pil_im.squeeze(axis=0)
-
-    assert np.allclose(iio_im, pil_im)
-
-
 def test_png_compression(test_images, tmp_path):
     # Note: Note sure if we should test this or pillow
 
@@ -476,7 +421,7 @@ def test_write_to_bytes():
 
     # writing to bytes with imageIO
     with io.BytesIO() as output:
-        iio.v3.imwrite(output, image, plugin="pillow", format="PNG")
+        iio.v3.imwrite(output, image, plugin="pillow", format_hint=".png")
         iio_contents = output.getvalue()
 
     assert iio_contents == contents
@@ -492,7 +437,7 @@ def test_write_to_bytes_rgba():
 
     # writing to bytes with imageIO
     with io.BytesIO() as output:
-        iio.v3.imwrite(output, image, plugin="pillow", format="PNG", mode="RGBA")
+        iio.v3.imwrite(output, image, plugin="pillow", format_hint=".png", mode="RGBA")
         iio_contents = output.getvalue()
 
     assert iio_contents == contents
@@ -507,7 +452,7 @@ def test_write_to_bytes_imwrite():
         contents = output.getvalue()
 
     # write with ImageIO
-    bytes_string = iio.v3.imwrite("<bytes>", image, plugin="pillow", format="PNG")
+    bytes_string = iio.v3.imwrite("<bytes>", image, plugin="pillow", format_hint=".png")
 
     assert contents == bytes_string
 
@@ -521,7 +466,9 @@ def test_write_to_bytes_jpg():
         contents = output.getvalue()
 
     # write with ImageIO
-    bytes_string = iio.v3.imwrite("<bytes>", image, plugin="pillow", format="JPEG")
+    bytes_string = iio.v3.imwrite(
+        "<bytes>", image, plugin="pillow", format_hint=".jpeg"
+    )
 
     assert contents == bytes_string
 
@@ -532,7 +479,7 @@ def test_write_jpg_to_bytes_io():
 
     image = np.zeros((200, 200), dtype=np.uint8)
     bytes_io = io.BytesIO()
-    iio.v3.imwrite(bytes_io, image, plugin="pillow", format="jpeg", mode="L")
+    iio.v3.imwrite(bytes_io, image, plugin="pillow", format_hint=".jpeg", mode="L")
     bytes_io.seek(0)
 
     image_from_file = iio.v3.imread(bytes_io, plugin="pillow")
@@ -638,3 +585,13 @@ def test_apng_reading(tmp_path, test_images):
             expected = np.asarray(frame)
             actual = all_frames[idx]
             assert np.allclose(actual, expected)
+
+
+def test_write_format_warning():
+    frames = iio.v3.imread("imageio:chelsea.png")
+    bytes_image = iio.v3.imwrite("<bytes>", frames, format_hint=".png", plugin="pillow")
+
+    with pytest.warns(UserWarning):
+        old_bytes = iio.v3.imwrite("<bytes>", frames, plugin="pillow", format="PNG")
+
+    assert bytes_image == old_bytes
